RootSignature

Struct RootSignature 

#[repr(transparent)]
pub struct RootSignature(pub ID3D12RootSignature);
The root signature defines what resources are bound to the graphics pipeline. A root signature is configured by the app and links command lists to the resources the shaders require. Currently, there is one graphics and one compute root signature per app.

For more information: ID3D12RootSignature interface

Tuple Fields

0: ID3D12RootSignature

Implementations

Source

impl RootSignature

pub fn serialize( desc: &RootSignatureDesc<'_>, version: RootSignatureVersion, ) -> Result<Blob, DxError>

Serializes a root signature version 1.0

For more information: D3D12SerializeRootSignature function