PrimitiveTopology

Enum PrimitiveTopology 

#[repr(i32)]
pub enum PrimitiveTopology { Undefined = 0, Point = 1, Line = 2, Triangle = 4, }
Values that indicate how the pipeline interprets vertex data that is bound to the input-assembler stage. These primitive topology values determine how the vertex data is rendered on screen.

For more information: D3D_PRIMITIVE_TOPOLOGY enumeration

Variants



Undefined = 0

The IA stage has not been initialized with a primitive topology. The IA stage will not function properly unless a primitive topology is defined.



Point = 1

Interpret the vertex data as a list of points.



Line = 2

Interpret the vertex data as a list of lines.



Triangle = 4

Interpret the vertex data as a list of triangles.

Implementations

Source

impl PrimitiveTopology

pub const fn from_repr(discriminant: i32) -> Option<PrimitiveTopology>

Try to create Self from the raw representation