#[repr(i32)]pub enum TextureLayout {
Unknown = 0,
RowMajor = 1,
UndefinedSwizzle64Kb = 2,
StandardSwizzle64Kb = 3,
}Expand description
Specifies texture layout options.
For more information: D3D12_TEXTURE_LAYOUT enumeration
Variants
Unknown = 0
Indicates that the layout is unknown, and is likely adapter-dependent.
During creation, the driver chooses the most efficient layout based on other resource properties, especially resource size and flags.
Prefer this choice unless certain functionality is required from another texture layout.
RowMajor = 1
Indicates that data for the texture is stored in row-major order (sometimes called “pitch-linear order”).
UndefinedSwizzle64Kb = 2
Indicates that the layout within 64KB tiles and tail mip packing is up to the driver.
StandardSwizzle64Kb = 3
Indicates that a default texture uses the standardized swizzle pattern.
Implementations
Sourceimpl TextureLayout
impl TextureLayout