#[repr(transparent)]pub struct Debug4(pub ID3D12Debug4);Expand description
Adds the ability to disable the debug layer.
For more information: ID3D12Debug4 interface
Tuple Fields
0: ID3D12Debug4Implementations
Sourceimpl Debug4
impl Debug4
Sourcepub fn enable_debug_layer(&self)
pub fn enable_debug_layer(&self)
Enables the debug layer.
For more information: ID3D12Debug::EnableDebugLayer method
Sourceimpl Debug4
impl Debug4
Sourcepub fn set_enable_gpu_based_validation(&self, enable: bool)
pub fn set_enable_gpu_based_validation(&self, enable: bool)
This method enables or disables GPU-Based Validation (GBV) before creating a device with the debug layer enabled.
For more information: ID3D12Debug1::SetEnableGPUBasedValidation method
Sourcepub fn set_enable_synchronized_command_queue_validation(&self, enable: bool)
pub fn set_enable_synchronized_command_queue_validation(&self, enable: bool)
Enables or disables dependent command queue synchronization when using a D3D12 device with the debug layer enabled.
For more information: ID3D12Debug1::SetEnableSynchronizedCommandQueueValidation method
Sourceimpl Debug4
impl Debug4
Sourcepub fn set_gpu_based_validation_flags(&self, flags: GpuBasedValidationFlags)
pub fn set_gpu_based_validation_flags(&self, flags: GpuBasedValidationFlags)
This method configures the level of GPU-based validation that the debug device is to perform at runtime.
For more information: ID3D12Debug2::SetGPUBasedValidationFlags method
Sourceimpl Debug4
impl Debug4
Sourcepub fn disable_debug_layer(&self)
pub fn disable_debug_layer(&self)
Disables the debug layer.
For more information: ID3D12Debug4::DisableDebugLayer method