#[repr(i32)]pub enum ComparisonFunc {
None = 0,
Never = 1,
Less = 2,
Equal = 3,
LessEqual = 4,
Greater = 5,
NotEqual = 6,
GreaterEqual = 7,
Always = 8,
}Expand description
Specifies comparison options.
For more information: D3D12_COMPARISON_FUNC enumeration
Variants
None = 0
None
Never = 1
Never pass the comparison.
Less = 2
If the source data is less than the destination data, the comparison passes.
Equal = 3
If the source data is equal to the destination data, the comparison passes.
LessEqual = 4
If the source data is less than or equal to the destination data, the comparison passes.
Greater = 5
If the source data is greater than the destination data, the comparison passes.
NotEqual = 6
If the source data is not equal to the destination data, the comparison passes.
GreaterEqual = 7
If the source data is greater than or equal to the destination data, the comparison passes.
Always = 8
Always pass the comparison.
Implementations