#[repr(i32)]pub enum ConservativeRasterizationTier {
NotSupported = 0,
Tier1 = 1,
Tier2 = 2,
Tier3 = 3,
}Expand description
Identifies the tier level of conservative rasterization.
For more information: D3D12_CONSERVATIVE_RASTERIZATION_TIER enumeration
Variants
NotSupported = 0
Conservative rasterization is not supported.
Tier1 = 1
Tier 1 enforces a maximum 1/2 pixel uncertainty region and does not support post-snap degenerates. This is good for tiled rendering, a texture atlas, light map generation and sub-pixel shadow maps.
Tier2 = 2
Tier 2 reduces the maximum uncertainty region to 1/256 and requires post-snap degenerates not be culled. This tier is helpful for CPU-based algorithm acceleration (such as voxelization).
Tier3 = 3
Tier 3 maintains a maximum 1/256 uncertainty region and adds support for inner input coverage. Inner input coverage adds the new value SV_InnerCoverage to
High Level Shading Language (HLSL). This is a 32-bit scalar integer that can be specified on input to a pixel shader, and represents the underestimated conservative
rasterization information (that is, whether a pixel is guaranteed-to-be-fully covered). This tier is helpful for occlusion culling.
Implementations