#[repr(i32)]pub enum IndexBufferStripCutValue {
Disabled = 0,
_0xFFFF = 1,
_0xFFFFFFFF = 2,
}Expand description
When using triangle strip primitive topology, vertex positions are interpreted as vertices of a continuous triangle “strip”. There is a special index value that represents the desire to have a discontinuity in the strip, the cut index value. This enum lists the supported cut values.
For more information: D3D12_INDEX_BUFFER_STRIP_CUT_VALUE enumeration
Variants
Disabled = 0
Indicates that there is no cut value.
_0xFFFF = 1
Indicates that 0xFFFF should be used as the cut value.
_0xFFFFFFFF = 2
Indicates that 0xFFFFFFFF should be used as the cut value.
Implementations