#[repr(i32)]pub enum ShaderInputType {
Show 14 variants
CBuffer = 0,
TBuffer = 1,
Texture = 2,
Sampler = 3,
UavRWTyped = 4,
Structured = 5,
UavRWStructured = 6,
ByteAddress = 7,
UavRwByteAddress = 8,
UavAppendStructured = 9,
UavConsumeStructured = 10,
UavRwstructuredWithCounter = 11,
RTAccelerationStructure = 12,
UavFeedbackTexture = 13,
}Expand description
Values that identify resource types that can be bound to a shader and that are reflected as part of the resource description for the shader.
For more information: D3D_SHADER_INPUT_TYPE enumeration
Variants
CBuffer = 0
TBuffer = 1
Texture = 2
Sampler = 3
UavRWTyped = 4
Structured = 5
UavRWStructured = 6
ByteAddress = 7
UavRwByteAddress = 8
UavAppendStructured = 9
UavConsumeStructured = 10
UavRwstructuredWithCounter = 11
RTAccelerationStructure = 12
UavFeedbackTexture = 13
Implementations